@@ -3,7 +3,7 @@ use warnings;
 use strict;
 use Unicode::CaseFold ();
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub new {
   my $class = shift;
@@ -49,10 +49,15 @@ sub new {
         $term_index += 1;
 
         # boundaries for the match
-        my ($start, $end) = ($-[0], $+[0]);
+        my $end   = pos($string);
+        my $term  = $&; # used to be slow in older perls, but now OK
+        my $start = $end - length($term);
 
-        # extract matched substring (more efficient than $&)
-        my $term = substr($string, $start, $end-$start);
+        # the old way used to be as follows, but it is ridiculously slow on utf8 strings
+        # .. see https://github.com/Perl/perl5/issues/18786
+        #
+        # my ($start, $end) = ($-[0], $+[0]); 
+        # my $term = substr($string, $start, $end-$start);
 
         # apply filtering and stopwords, if any
         $term = Unicode::CaseFold::fc($term) if $lower;
@@ -358,50 +363,11 @@ L<Text::Transliterator::Unaccent|Text::Transliterator::Unaccent>
 
 =head1 AUTHOR
 
-Laurent Dami, C<< <lau.....da..@justice.ge.ch> >>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-search-tokenizer
-at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Search-Tokenizer>.  I
-will be notified, and then you'll automatically be notified of
-progress on your bug as I make changes.
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Search::Tokenizer
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Search-Tokenizer>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Search-Tokenizer>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Search-Tokenizer>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Search-Tokenizer/>
-
-=back
-
+Laurent Dami, C<< <dami@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Laurent Dami.
+Copyright 2010, 2021 Laurent Dami.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
